@@ -25,6 +25,8 @@ from ._version import _DOCS_URL, _KEYWORDS
 from ._service_class import ServiceClass
 from ._util import confirm_base_region, confirm_base_url
 from ._base_url import BaseURL
+from ._container_base_url import ContainerBaseURL
+from .alerts import Alerts
 from .api_complete import APIHarness
 from .cloud_connect_aws import CloudConnectAWS
 from .cspm_registration import CSPMRegistration
@@ -53,6 +55,7 @@ from .kubernetes_protection import KubernetesProtection
 from .malquery import MalQuery
 from .message_center import MessageCenter
 from .ml_exclusions import MLExclusions
+from .mobile_enrollment import MobileEnrollment
 from .mssp import FlightControl
 from .oauth2 import OAuth2
 from .overwatch_dashboard import OverwatchDashboard
@@ -85,7 +88,7 @@ __project_url__ = _PROJECT_URL
 __docs_url__ = _DOCS_URL
 __keywords__ = _KEYWORDS
 __all__ = [
-    "confirm_base_url", "confirm_base_region", "BaseURL", "ServiceClass",
+    "confirm_base_url", "confirm_base_region", "BaseURL", "ServiceClass", "Alerts",
     "APIHarness", "CloudConnectAWS", "CSPMRegistration", "CustomIOA", "D4CRegistration",
     "Detects", "DeviceControlPolicies", "Discover", "EventStreams", "CompleteDashboard",
     "FalconContainer", "FalconXSandbox", "FirewallManagement", "FirewallPolicies", "HostGroup",
@@ -96,7 +99,7 @@ __all__ = [
     "ScheduledReports", "SensorDownload", "SensorUpdatePolicy", "SensorVisibilityExclusions",
     "SpotlightVulnerabilities", "SpotlightEvaluationLogic", "UserManagement",
     "ZeroTrustAssessment", "PreventionPolicies", "SensorUpdatePolicies", "MessageCenter",
-    "FileVantage"
+    "FileVantage", "MobileEnrollment", "ContainerBaseURL"
 ]
 """
 This is free and unencumbered software released into the public domain.
