@@ -184,13 +184,6 @@ _firewall_management_endpoints = [
     "Update an identified policy container",
     "firewall_management",
     [
-      {
-        "type": "string",
-        "description": "The user id",
-        "name": "X-CS-USERNAME",
-        "in": "header",
-        "required": True
-      },
       {
         "name": "body",
         "in": "body",
@@ -225,13 +218,6 @@ _firewall_management_endpoints = [
     "Create new rule group on a platform for a customer with a name and description, and return the ID",
     "firewall_management",
     [
-      {
-        "type": "string",
-        "description": "The user id",
-        "name": "X-CS-USERNAME",
-        "in": "header",
-        "required": True
-      },
       {
         "type": "string",
         "description": "A rule group ID from which to copy rules. "
@@ -266,13 +252,6 @@ _firewall_management_endpoints = [
     "Update name, description, or enabled status of a rule group, or create, edit, delete, or reorder rules",
     "firewall_management",
     [
-      {
-        "type": "string",
-        "description": "The user id",
-        "name": "X-CS-USERNAME",
-        "in": "header",
-        "required": True
-      },
       {
         "type": "string",
         "description": "Audit log comment for this action",
@@ -293,13 +272,6 @@ _firewall_management_endpoints = [
     "Delete rule group entities by ID",
     "firewall_management",
     [
-      {
-        "type": "string",
-        "description": "The user id",
-        "name": "X-CS-USERNAME",
-        "in": "header",
-        "required": True
-      },
       {
         "type": "array",
         "items": {
