@@ -149,6 +149,13 @@ _host_group_endpoints = [
         "in": "query",
         "required": True
       },
+      {
+        "type": "boolean",
+        "default": False,
+        "description": "Bool to disable hostname check on add-member",
+        "name": "disable_hostname_check",
+        "in": "query"
+      },
       {
         "name": "body",
         "in": "body",
