@@ -83,6 +83,16 @@ _real_time_response_endpoints = [
         "name": "timeout_duration",
         "in": "query"
       },
+      {
+        "type": "string",
+        "default": "tiny bit less than overall request timeout",
+        "description": "Timeout duration for how long a host has time to complete processing. "
+        "Default value is a bit less than the overall timeout value. It cannot be greater than "
+        "the overall request timeout. Maximum is < 10 minutes. "
+        "Example, `10s`. Valid units: `ns, us, ms, s, m, h`. ",
+        "name": "host_timeout_duration",
+        "in": "query"
+      },
       {
         "description": "Use this endpoint to run these [real time response commands]"
         "(https://falcon.crowdstrike.com/support/documentation/11/getting-started-guide#rtr_commands):"
@@ -126,6 +136,16 @@ _real_time_response_endpoints = [
         "name": "timeout_duration",
         "in": "query"
       },
+      {
+        "type": "string",
+        "default": "tiny bit less than overall request timeout",
+        "description": "Timeout duration for how long a host has time to complete processing. "
+        "Default value is a bit less than the overall timeout value. It cannot be greater than "
+        "the overall request timeout. Maximum is < 10 minutes. "
+        "Example, `10s`. Valid units: `ns, us, ms, s, m, h`. ",
+        "name": "host_timeout_duration",
+        "in": "query"
+      },
       {
         "description": "Use this endpoint to run these [real time response commands]"
         "(https://falcon.crowdstrike.com/support/documentation/11/getting-started-guide#rtr_commands):\n- "
@@ -200,6 +220,16 @@ _real_time_response_endpoints = [
         "name": "timeout_duration",
         "in": "query"
       },
+      {
+        "type": "string",
+        "default": "tiny bit less than overall request timeout",
+        "description": "Timeout duration for how long a host has time to complete processing. "
+        "Default value is a bit less than the overall timeout value. It cannot be greater than "
+        "the overall request timeout. Maximum is < 10 minutes. "
+        "Example, `10s`. Valid units: `ns, us, ms, s, m, h`. ",
+        "name": "host_timeout_duration",
+        "in": "query"
+      },
       {
         "description": "**`batch_id`** Batch ID to execute the command on.  "
         "Received from `/real-time-response/combined/init-sessions/v1`.\n**`file_path`** "
@@ -236,6 +266,16 @@ _real_time_response_endpoints = [
         "name": "timeout_duration",
         "in": "query"
       },
+      {
+        "type": "string",
+        "default": "tiny bit less than overall request timeout",
+        "description": "Timeout duration for how long a host has time to complete processing. "
+        "Default value is a bit less than the overall timeout value. It cannot be greater than "
+        "the overall request timeout. Maximum is < 10 minutes. "
+        "Example, `10s`. Valid units: `ns, us, ms, s, m, h`. ",
+        "name": "host_timeout_duration",
+        "in": "query"
+      },
       {
         "description": "**`host_ids`** List of host agent ID's to initialize a RTR session on\n**`existing_batch_id`** "
         "Optional batch ID. Use an existing batch ID if you want to initialize new hosts and add them to the existing batch",
