@@ -200,6 +200,26 @@ _real_time_response_admin_endpoints = [
       }
     ]
   ],
+  [
+    "RTR_GetPut_FilesV2",
+    "GET",
+    "/real-time-response/entities/put-files/v2",
+    "Get put-files based on the ID's given. These are used for the RTR `put` command.",
+    "real_time_response_admin",
+    [
+      {
+        "type": "array",
+        "items": {
+          "type": "string"
+        },
+        "collectionFormat": "multi",
+        "description": "File IDs",
+        "name": "ids",
+        "in": "query",
+        "required": True
+      }
+    ]
+  ],
   [
     "RTR_GetScripts",
     "GET",
@@ -370,6 +390,26 @@ _real_time_response_admin_endpoints = [
       }
     ]
   ],
+  [
+    "RTR_GetScriptsV2",
+    "GET",
+    "/real-time-response/entities/scripts/v2",
+    "Get custom-scripts based on the ID's given. These are used for the RTR `runscript` command.",
+    "real_time_response_admin",
+    [
+      {
+        "type": "array",
+        "items": {
+          "type": "string"
+        },
+        "collectionFormat": "multi",
+        "description": "File IDs",
+        "name": "ids",
+        "in": "query",
+        "required": True
+      }
+    ]
+  ],
   [
     "RTR_ListPut_Files",
     "GET",
