@@ -60,19 +60,6 @@ _report_executions_endpoints = [
     "This endpoint will be used to retry report executions",
     "report_executions",
     [
-      {
-        "type": "string",
-        "description": "The user id",
-        "name": "X-CS-USERID",
-        "in": "header"
-      },
-      {
-        "type": "string",
-        "description": "The user uuid",
-        "name": "X-CS-USERUUID",
-        "in": "header",
-        "required": True
-      },
       {
         "name": "body",
         "in": "body",
