@@ -43,6 +43,7 @@ from ._firewall import firewall_policy_payload, firewall_container_payload
 from ._firewall import firewall_rule_group_payload, firewall_rule_group_update_payload
 from ._reports import reports_payload
 from ._message_center import activity_payload, case_payload
+from ._alerts import update_alerts_payload
 
 
 __all__ = [
@@ -57,5 +58,5 @@ __all__ = [
     "cspm_policy_payload", "cspm_scan_payload", "device_policy_payload", "falconx_payload",
     "mssp_payload", "ioa_custom_payload", "firewall_policy_payload", "firewall_container_payload",
     "firewall_rule_group_payload", "firewall_rule_group_update_payload", "reports_payload",
-    "activity_payload", "case_payload", "incident_action_parameters"
+    "activity_payload", "case_payload", "incident_action_parameters", "update_alerts_payload"
 ]
